@@ -19,6 +19,9 @@ class Constants:
 
         fair_neutral_threshold_high : float
                 Fairness neutral threshold maximum value
+        
+        fair_neutral_tolerance : float
+                Fairness neutral tolerance
 
         proportion_of_interpolation_fitting_low : float
                 Proportion of interpolation fitting minumum value
@@ -28,6 +31,21 @@ class Constants:
 
         selection_threshold : float
                 Selection threshold
+        
+        tradeoff_threshold_bins : float
+                Tradeoff threshold bins
+
+        tradeoff_uplift_min_threshold: float
+                Tradeoff uplift minimum threshold
+
+        tradeoff_uplift_max_threshold : float
+                Tradeoff uplift maximum threshold
+
+        tradeoff_min_threshold: float
+                Tradeoff minimum threshold
+
+        tradeoff_max_threshold: float
+                Tradeoff maximum threshold
 
         k : int
                 Number of samples to calculate confidence interval
