@@ -1,11 +1,11 @@
 import numpy as np
 from sklearn.metrics import confusion_matrix
 from .fairness import Fairness
-from ..utility import check_datatype, check_value
-from ..performance_metrics import PerformanceMetrics
-from .fairness_metrics import FairnessMetrics
+from ..util.utility import check_datatype, check_value
+from ..metrics.performance_metrics import PerformanceMetrics
+from ..metrics.fairness_metrics import FairnessMetrics
 from ..config.constants import Constants
-from ..ErrorCatcher import VeritasError
+from ..util.errors import *
 
 class CustomerMarketing(Fairness):
     """
@@ -38,7 +38,7 @@ class CustomerMarketing(Fairness):
 
         Instance Attributes
         ------------------
-        perf_metric_name: string, default = ‘balanced_acc’
+        perf_metric_name: string, default = "balanced_acc"
                 Name of the primary performance metric to be used for computations in the evaluate() and/or compile() functions.
 
         fair_metric_name : string, default = "auto"
@@ -53,22 +53,22 @@ class CustomerMarketing(Fairness):
         fair_impact: string, default = "normal"
                 Used to pick the fairness metric according to the Fairness Tree methodology. Could be "normal" or "significant" or "selective"
 
-        fair_neutral_tolerance: float, default = 0.001
-                Tolerance value between 0 and 0.1 (inclusive) used in the performance-fairness tradeoff analysis section to filter the primary fairness metric values.
-
-        treatment_cost: float, default=None
+        treatment_cost: int or float, default=None
                 Cost of the marketing treatment per customer
 
-        revenue: float, default=None
+        revenue: int or float, default=None
                 Revenue gained per customer
 
         fairness_metric_value_input : dictionary
+                Contains the p_var and respective fairness_metric and value 
+                e.g. {"gender": {"fnr_parity": 0.2}}
 
         proportion_of_interpolation_fitting : float, default=1.0
+                Proportion of interpolation fitting
 
-        _use_case_metrics: dictionary of lists, default="None"
-                Contains all the performance & fairness metrics for credit scoring.
-                e.g. {"fair ": ["fnr_parity", ...], "perf": ["balanced_accuracy, ..."]}
+        _use_case_metrics: dictionary of lists, default=None
+                Contains all the performance & fairness metrics for each use case.
+                e.g. {"fair ": ["fnr_parity", ...], "perf": ["balanced_acc, ..."]}
                 Dynamically assigned during initialisation by using the _metric_group_map in Fairness/Performance Metrics class and the _model_type_to_metric above.
 
         _input_validation_lookup: dictionary
@@ -94,6 +94,14 @@ class CustomerMarketing(Fairness):
         err : object
                 VeritasError object
 
+        selection_threshold : float
+                Selection threshold from Constants class
+
+        e_lift : float
+                Empirical lift
+
+        pred_outcome: dictionary
+                Contains the probabilities of the treatment and control groups for both rejection and acquiring
         """
         super().__init__(model_params)
 
@@ -110,11 +118,10 @@ class CustomerMarketing(Fairness):
         self.proportion_of_interpolation_fitting = proportion_of_interpolation_fitting
 
         self._model_type_input()
-        # ch_model = self._model_type_input()
-        # if ch_model != []:
-        #     self.err.push(ch_model[0][0], var_name=ch_model[0][1], given=ch_model[0][2], expected=ch_model[0][3])
 
         self._select_fairness_metric_name()
+        self.check_perf_metric_name()
+        self.check_fair_metric_name()
 
         self._use_case_metrics = {}
 
@@ -163,96 +170,58 @@ class CustomerMarketing(Fairness):
         """
         err = VeritasError()
         check_datatype(self)
-        # ch_datatype_msg = check_datatype(self)
-        # if type(ch_datatype_msg) == str:
-        #     print(ch_datatype_msg)
-        # else:
-        #     err.push(ch_datatype_msg[0][0], var_name=ch_datatype_msg[0][1], given=ch_datatype_msg[0][2],
-        #              expected=ch_datatype_msg[0][3], function_name="_check_input")
+
         check_value(self)
-        # ch_value_msg = check_value(self)
-        # if type(ch_value_msg) == str:
-        #     print(ch_value_msg)
-        # else:
-        #     err.push(ch_value_msg[0][0], var_name=ch_value_msg[0][1], given=ch_value_msg[0][2],
-        #              expected=ch_value_msg[0][3], function_name="_check_input")
 
         # Check for length of model_params
-        # mp_errmsg = "\n The given length of model_params is {}. \n The expected length of model_params is {}."
         mp_g = len(self.model_params)
         mp_e = self._model_type_to_metric_lookup[self.model_params[0].model_type][2]
         if mp_g != mp_e:
             err.push('length_error', var_name="model_params", given=str(mp_g), expected= str(mp_e), function_name="_check_input")
 
         self._base_input_check()
-        # ch_input = self._base_input_check()
-        # if ch_input != []:
-        #     err.push(ch_input[0][0], var_name_a=ch_value_msg[0][1], some_string=ch_input[0][2],
-        #                   value=ch_input[0][3], function_name="_check_input")
+
         self._fairness_metric_value_input_check()
 
-        # ch_fair_metric_value = self._fairness_metric_value_input_check()
-        # if ch_fair_metric_value != []:
-        #     err.push(ch_fair_metric_value[0][0], var_name=ch_fair_metric_value[0][1],
-        #                   given=ch_fair_metric_value[0][2],
-        #                   expected=ch_fair_metric_value[0][3], function_name="_check_input")
-            
-
-
         #check for y_prob not None if model is uplift, else check for y_pred not None
         if self.model_params[0].model_type  == "uplift":
-            #y_prob_errmsg = "\n The given dtype of y_prob is {}. \n The expected dtype of y_prob is {}."
             for i in range(len(self.model_params)):
                 if self.model_params[i].y_prob is None:
                     err.push('type_error', var_name="y_prob", given= "type None", expected="type [list, np.ndarray, pd.Series]", function_name="_check_input")
-                    #raise TypeError(y_prob_errmsg.format(str(y_prob_given), str(y_prob_expected)))
         else:
-            #y_pred_errmsg = "\n The given dtype of y_pred is {}. \n The expected dtype of y_pred is {}."
             for i in range(len(self.model_params)):
                 if self.model_params[i].y_pred is None:
                     err.push('type_error', var_name="y_pred", given= "type None", expected="type [list, np.ndarray, pd.Series]", function_name="_check_input")
-                    #raise TypeError(y_pred_errmsg.format(str(y_pred_given), str(y_pred_expected)))
 
-         #check if y_pred is provided but model_type is uplift, set y_pred = None
         if self.model_params[0].model_type == 'uplift' and self.model_params[0].y_pred is not None:
-            #self.model_params[0].y_pred = None
             for i in range(len(self.model_params)):
                 self.model_params[i].y_pred = None
-
+        
+        if self.model_params[0].y_prob is not None:
+            if self.model_params[0].y_prob.dtype.kind == "i":
+                err.push('type_error', var_name="y_prob", given= "type int", expected="type float", function_name="_check_input")
 
         #Check for revenue and treatment_cost
-        # r_tc_less = "\n The given value of revenue is {} and treatment_cost is {}. \n The expected value of revenue cannot be less than treatment_cost."
         if self.model_params[0].model_type == 'uplift' and self.perf_metric_name == "expected_profit":
-        #if self.model_params[0].model_type == 'uplift':
-            # errMsg = "data type error"
-            # errMsgFormat = "\n    {}: given {}, expected {}"
             exp_type = list((int, float))
             spl_range = (0, np.inf)
             for i in self.spl_params.keys() :
                 if type(self.spl_params[i]) not in exp_type :
-                    # errMsg += errMsgFormat.format(str(i),type(self.spl_params[i]), exp_type)
-                    # raise ValueError(errMsg)
                     err.push('type_error', var_name=str(i), given=type(self.spl_params[i]), expected=exp_type, function_name="_check_input")
-            
-                        
-            # errMsg = "data value error"
-            # errMsgFormat = "\n    {}: given {:.{decimal_pts}}, expected in range {}"
-            # spl_range = (0, np.inf)
+
                 try:
                     if type(self.spl_params[i]) != type(None):
                         if  self.spl_params[i] < spl_range[0]  or self.spl_params[i] > spl_range[1] :
-                        # errMsg += errMsgFormat.format(i, self.spl_params[i], str(spl_range), decimal_pts=self.decimals)
-                        # raise ValueError(errMsg)
                             err.push('value_error', var_name=str(i), given=self.spl_params[i],  expected="range " + str(spl_range), function_name="_check_input")
                 except:
                     pass
             try:
                 if self.spl_params['revenue'] < self.spl_params['treatment_cost']:
-                    # raise ValueError (r_tc_less.format(str(self.spl_params['revenue']), str(self.spl_params['treatment_cost'])))
                     err.push('value_error_compare', var_name_a="revenue", var_name_b="treatment_cost", function_name="_check_input")
             except:
                 pass
-
+        
+        
         err.pop()
     
     def _get_confusion_matrix(self, y_true, y_pred, sample_weight, curr_p_var = None, feature_mask = None, **kwargs):
@@ -318,17 +287,11 @@ class CustomerMarketing(Fairness):
     
             else:
                 return [None] * 8
-        
-        
-
+    
     def _select_fairness_metric_name(self):
         """
-        Retrieves the fairness metric name based on the values of model_type, fair_concern, fair_impact, fair_priority.
-
-        Returns
-        ---------
-        self.fair_metric_name : string
-                Name of the primary fairness metric to be used for computations in the evaluate() and/or compile() functions
+        Retrieves the fairness metric name based on the values of model_type, fair_concern, fair_impact and fair_priority.
+        Name of the primary fairness metric to be used for computations in the evaluate() and/or compile() functions                
         """
         if self.fair_metric_name == 'auto':
             if self.model_params[0].model_type == 'uplift':
@@ -341,19 +304,6 @@ class CustomerMarketing(Fairness):
                 self._fairness_tree(is_pos_label_favourable)
         else :
             self.fair_metric_name
-        # try:
-        if FairnessMetrics.map_fair_metric_to_group[self.fair_metric_name][4] == False:
-            err = VeritasError()
-            ratio_parity_metrics = []
-            for i,j in FairnessMetrics.map_fair_metric_to_group.items():
-                if j[1] == self._model_type_to_metric_lookup[self.model_params[0].model_type][0]:
-                    if j[2] == "ratio" or j[2] == "parity":
-                        ratio_parity_metrics.append(i)
-            err.push('value_error', var_name="fair_metric_name", given=self.fair_metric_name,  expected=ratio_parity_metrics, function_name="_select_fairness_metric_name")
-            err.pop()
-        # except:
-            # pass
-
 
     def _get_e_lift(self, **kwargs):
         """
@@ -410,11 +360,9 @@ class CustomerMarketing(Fairness):
 
         if self.model_params[0].model_type == 'uplift':
 
-            #self.y_true = [model.y_true for model in self.use_case_object.model_params]
             y_prob = [model.y_prob for model in self.model_params]
             y_train = [model.y_train  if model.y_train is not None else model.y_true for model in self.model_params]        
                         
-                
             if 'y_pred_new' in kwargs:
                 y_prob = kwargs['y_pred_new']
 
@@ -435,10 +383,9 @@ class CustomerMarketing(Fairness):
                 pOcC = y_prob_temp[:, 2] / pC
                 pred_outcome[model_alias[i] + 'treatment'] = pOcT
                 pred_outcome[model_alias[i] + 'control'] = pOcC
-        
             return pred_outcome
-        
+
         else :
             return None
 
-            
+            
\ No newline at end of file
